@@ -321,12 +321,10 @@ ushort Recurrence::recurrenceType(const RecurrenceRule *rrule)
         } else {
             return rYearlyMonth;
         }
-        break;
     }
     default:
         return rOther;
     }
-    return rOther;
 }
 
 bool Recurrence::recursOn(const QDate &qd, const QTimeZone &timeZone) const
@@ -1471,8 +1469,6 @@ void Recurrence::recurrenceChanged(RecurrenceRule *)
 
 void Recurrence::dump() const
 {
-    qCDebug(KCALCORE_LOG);
-
     int i;
     int count = d->mRRules.count();
     qCDebug(KCALCORE_LOG) << "  -)" << count << "RRULEs:";
